Crate litutil

Crate litutil 

this library provides several proc macros that can be called from declarative macros in order to manipulate literals.

Macros

into_bytestr
convert any type of string literal into a bytestring literal.
into_cstr
convert any type of string literal into a c string literal.
into_str
convert any type of string literal into a plain string literal.